# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zlint.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='zlint.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x0bzlint.proto\x12\x07zsearch\"H\n\nLintResult\x12)\n\x06result\x18\x01 \x01(\x0e\x32\x19.zsearch.LintResultStatus\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"\xea\x01\n\x05ZLint\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12$\n\x06status\x18\x03 \x01(\x0e\x32\x14.zsearch.ZLintStatus\x12\x15\n\rinfos_present\x18\x04 \x01(\x08\x12\x17\n\x0fnotices_present\x18\x05 \x01(\x08\x12\x18\n\x10warnings_present\x18\x06 \x01(\x08\x12\x16\n\x0e\x65rrors_present\x18\x07 \x01(\x08\x12\x16\n\x0e\x66\x61tals_present\x18\x08 \x01(\x08\x12\x1d\n\x05lints\x18\t \x01(\x0b\x32\x0e.zsearch.Lints\"\x9e[\n\x05Lints\x12=\n e_basic_constraints_not_critical\x18\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x30\n\x13\x65_ian_bare_wildcard\x18\x02 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_ian_wildcard_not_first\x18\x03 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x30\n\x13\x65_san_bare_wildcard\x18\x04 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_san_wildcard_not_first\x18\x05 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19\x65_ca_country_name_invalid\x18\x06 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19\x65_ca_country_name_missing\x18\x07 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x32\n\x15\x65_ca_crl_sign_not_set\x18\x08 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1en_ca_digital_signature_not_set\x18\t \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x1a\x65_ca_key_cert_sign_not_set\x18\n \x01(\x0b\x32\x13.zsearch.LintResult\x12\x33\n\x16\x65_ca_key_usage_missing\x18\x0b \x01(\x0b\x32\x13.zsearch.LintResult\x12\x38\n\x1b\x65_ca_key_usage_not_critical\x18\x0c \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_ca_organization_name_missing\x18\r \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_ca_subject_field_empty\x18\x0e \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_cert_contains_unique_identifier\x18\x0f \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_cert_extensions_version_not_3\x18\x10 \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n e_cab_dv_conflicts_with_locality\x18\x11 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x38\n\x1b\x65_cab_dv_conflicts_with_org\x18\x12 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_cab_dv_conflicts_with_postal\x18\x13 \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n e_cab_dv_conflicts_with_province\x18\x14 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_cab_dv_conflicts_with_street\x18\x15 \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_cert_policy_iv_requires_country\x18\x16 \x01(\x0b\x32\x13.zsearch.LintResult\x12K\n.e_cert_policy_iv_requires_province_or_locality\x18\x17 \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_cert_policy_ov_requires_country\x18\x18 \x01(\x0b\x32\x13.zsearch.LintResult\x12K\n.e_cert_policy_ov_requires_province_or_locality\x18\x19 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x32\n\x15\x65_cab_ov_requires_org\x18\x1a \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_cab_iv_requires_personal_name\x18\x1b \x01(\x0b\x32\x13.zsearch.LintResult\x12H\n+e_cert_unique_identifier_version_not_2_or_3\x18\x1c \x01(\x0b\x32\x13.zsearch.LintResult\x12\x30\n\x13\x65_dh_params_missing\x18\x1d \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_distribution_point_incomplete\x18\x1e \x01(\x0b\x32\x13.zsearch.LintResult\x12\x45\n(w_distribution_point_missing_ldap_or_uri\x18\x1f \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n&e_dsa_improper_modulus_or_divisor_size\x18  \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_dsa_shorter_than_2048_bits\x18! \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_ec_improper_curves\x18\" \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19w_eku_critical_improperly\x18# \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_ev_business_category_missing\x18$ \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19\x65_ev_country_name_missing\x18% \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x1a\x65_ev_locality_name_missing\x18& \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_ev_organization_name_missing\x18\' \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x1a\x65_ev_serial_number_missing\x18( \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_ev_valid_time_too_long\x18) \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!w_ext_aia_access_location_missing\x18* \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19\x65_ext_aia_marked_critical\x18+ \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n\'e_ext_authority_key_identifier_critical\x18, \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n&e_ext_authority_key_identifier_missing\x18- \x01(\x0b\x32\x13.zsearch.LintResult\x12M\n0e_ext_authority_key_identifier_no_key_identifier\x18. \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n$w_ext_cert_policy_contains_noticeref\x18/ \x01(\x0b\x32\x13.zsearch.LintResult\x12N\n1e_ext_cert_policy_disallowed_any_policy_qualifier\x18\x30 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x38\n\x1b\x65_ext_cert_policy_duplicate\x18\x31 \x01(\x0b\x32\x13.zsearch.LintResult\x12G\n*e_ext_cert_policy_explicit_text_ia5_string\x18\x32 \x01(\x0b\x32\x13.zsearch.LintResult\x12M\n0w_ext_cert_policy_explicit_text_includes_control\x18\x33 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n\'w_ext_cert_policy_explicit_text_not_nfc\x18\x34 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x45\n(w_ext_cert_policy_explicit_text_not_utf8\x18\x35 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x45\n(e_ext_cert_policy_explicit_text_too_long\x18\x36 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n&w_ext_crl_distribution_marked_critical\x18\x37 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19\x65_ext_duplicate_extension\x18\x38 \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n\"e_ext_freshest_crl_marked_critical\x18\x39 \x01(\x0b\x32\x13.zsearch.LintResult\x12/\n\x12w_ext_ian_critical\x18: \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_ian_dns_not_ia5_string\x18; \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_ext_ian_empty_name\x18< \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_ext_ian_no_entries\x18= \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_ext_ian_rfc822_format_invalid\x18> \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_ext_ian_space_dns_name\x18? \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_ian_uri_format_invalid\x18@ \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_ext_ian_uri_host_not_fqdn_or_ip\x18\x41 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x32\n\x15\x65_ext_ian_uri_not_ia5\x18\x42 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x33\n\x16\x65_ext_ian_uri_relative\x18\x43 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n$e_ext_key_usage_cert_sign_without_ca\x18\x44 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1cw_ext_key_usage_not_critical\x18\x45 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_key_usage_without_bits\x18\x46 \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n#e_ext_name_constraints_not_critical\x18G \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n e_ext_name_constraints_not_in_ca\x18H \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_ext_policy_constraints_empty\x18I \x01(\x0b\x32\x13.zsearch.LintResult\x12\x42\n%e_ext_policy_constraints_not_critical\x18J \x01(\x0b\x32\x13.zsearch.LintResult\x12\x38\n\x1b\x65_ext_policy_map_any_policy\x18K \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1dw_ext_policy_map_not_critical\x18L \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n#w_ext_policy_map_not_in_cert_policy\x18M \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_ext_san_contains_reserved_ip\x18N \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n\"w_ext_san_critical_with_subject_dn\x18O \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n e_ext_san_directory_name_present\x18P \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_san_dns_not_ia5_string\x18Q \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x1a\x65_ext_san_dnsname_not_fqdn\x18S \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n e_ext_san_edi_party_name_present\x18T \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_ext_san_empty_name\x18U \x01(\x0b\x32\x13.zsearch.LintResult\x12.\n\x11\x65_ext_san_missing\x18V \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_ext_san_no_entries\x18W \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n&e_ext_san_not_critical_without_subject\x18X \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_san_other_name_present\x18Y \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_ext_san_registered_id_present\x18Z \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1f\x65_ext_san_rfc822_format_invalid\x18[ \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1d\x65_ext_san_rfc822_name_present\x18\\ \x01(\x0b\x32\x13.zsearch.LintResult\x12\x35\n\x18\x65_ext_san_space_dns_name\x18] \x01(\x0b\x32\x13.zsearch.LintResult\x12J\n-e_ext_san_uniform_resource_identifier_present\x18^ \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1c\x65_ext_san_uri_format_invalid\x18_ \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_ext_san_uri_host_not_fqdn_or_ip\x18` \x01(\x0b\x32\x13.zsearch.LintResult\x12\x32\n\x15\x65_ext_san_uri_not_ia5\x18\x61 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x33\n\x16\x65_ext_san_uri_relative\x18\x62 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x42\n%e_ext_subject_directory_attr_critical\x18\x63 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x42\n%e_ext_subject_key_identifier_critical\x18\x64 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n\'e_ext_subject_key_identifier_missing_ca\x18\x65 \x01(\x0b\x32\x13.zsearch.LintResult\x12J\n-w_ext_subject_key_identifier_missing_sub_cert\x18\x66 \x01(\x0b\x32\x13.zsearch.LintResult\x12H\n+e_generalized_time_does_not_include_seconds\x18g \x01(\x0b\x32\x13.zsearch.LintResult\x12I\n,e_generalized_time_includes_fraction_seconds\x18h \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1e\x65_generalized_time_not_in_zulu\x18i \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x1aw_gtld_under_consideration\x18j \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_ian_dns_name_includes_null_char\x18k \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_ian_dns_name_starts_with_period\x18l \x01(\x0b\x32\x13.zsearch.LintResult\x12\x38\n\x1bw_ian_iana_pub_suffix_empty\x18m \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n!e_inhibit_any_policy_not_critical\x18n \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1d\x65_invalid_certificate_version\x18o \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x14\x65_issuer_field_empty\x18p \x01(\x0b\x32\x13.zsearch.LintResult\x12\x34\n\x17\x65_name_constraint_empty\x18q \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n$e_name_constraint_maximum_not_absent\x18r \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n\"e_name_constraint_minimum_non_zero\x18s \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n#w_name_constraint_on_edi_party_name\x18t \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n\"w_name_constraint_on_registered_id\x18u \x01(\x0b\x32\x13.zsearch.LintResult\x12\x36\n\x19w_name_constraint_on_x400\x18v \x01(\x0b\x32\x13.zsearch.LintResult\x12\x46\n)e_old_root_ca_rsa_mod_less_than_2048_bits\x18w \x01(\x0b\x32\x13.zsearch.LintResult\x12\x45\n(e_old_sub_ca_rsa_mod_less_than_1024_bits\x18x \x01(\x0b\x32\x13.zsearch.LintResult\x12G\n*e_old_sub_cert_rsa_mod_less_than_1024_bits\x18y \x01(\x0b\x32\x13.zsearch.LintResult\x12\x46\n)e_path_len_constraint_improperly_included\x18z \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n\"e_path_len_constraint_zero_or_less\x18{ \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1d\x65_public_key_type_not_allowed\x18| \x01(\x0b\x32\x13.zsearch.LintResult\x12Z\n=w_root_ca_basic_constraints_path_len_constraint_field_present\x18} \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1ew_root_ca_contains_cert_policy\x18~ \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n$e_root_ca_extended_key_usage_present\x18\x7f \x01(\x0b\x32\x13.zsearch.LintResult\x12\x30\n\x12\x65_rsa_exp_negative\x18\x80\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n\"w_rsa_mod_factors_smaller_than_752\x18\x81\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1d\x65_rsa_mod_less_than_2048_bits\x18\x82\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12/\n\x11w_rsa_mod_not_odd\x18\x83\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n\"w_rsa_public_exponent_not_in_range\x18\x84\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1d\x65_rsa_public_exponent_not_odd\x18\x85\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n\x1f\x65_rsa_public_exponent_too_small\x18\x86\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n!e_san_dns_name_includes_null_char\x18\x87\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12?\n!e_san_dns_name_starts_with_period\x18\x88\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1bw_san_iana_pub_suffix_empty\x18\x89\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n%e_serial_number_longer_than_20_octets\x18\x8a\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1c\x65_serial_number_not_positive\x18\x8b\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12J\n,w_sub_ca_aia_does_not_contain_issuing_ca_url\x18\x8c\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n&e_sub_ca_aia_does_not_contain_ocsp_url\x18\x8d\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x32\n\x14\x65_sub_ca_aia_missing\x18\x8e\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12K\n-w_sub_ca_certificate_policies_marked_critical\x18\x8f\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n%e_sub_ca_certificate_policies_missing\x18\x90\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12S\n5e_sub_ca_crl_distribution_points_does_not_contain_url\x18\x91\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12N\n0e_sub_ca_crl_distribution_points_marked_critical\x18\x92\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x46\n(e_sub_ca_crl_distribution_points_missing\x18\x93\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x33\n\x15w_sub_ca_eku_critical\x18\x94\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n&w_sub_ca_name_constraints_not_critical\x18\x95\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n e_sub_ca_no_dns_name_constraints\x18\x96\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n\x1f\x65_sub_ca_no_ip_name_constraints\x18\x97\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12L\n.e_sub_cert_aia_does_not_contain_issuing_ca_url\x18\x98\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x46\n(e_sub_cert_aia_does_not_contain_ocsp_url\x18\x99\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x34\n\x16\x65_sub_cert_aia_missing\x18\x9a\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1c\x65_sub_cert_cert_policy_empty\x18\x9b\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12M\n/w_sub_cert_certificate_policies_marked_critical\x18\x9c\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12U\n7e_sub_cert_crl_distribution_points_does_not_contain_url\x18\x9d\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12P\n2e_sub_cert_crl_distribution_points_marked_critical\x18\x9e\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1bw_sub_cert_eku_extra_values\x18\x9f\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x34\n\x16\x65_sub_cert_eku_missing\x18\xa0\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12L\n.e_sub_cert_eku_server_auth_client_auth_missing\x18\xa1\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x44\n&e_sub_cert_key_usage_cert_sign_bit_set\x18\xa2\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12=\n\x1f\x65_sub_cert_or_sub_ca_using_sha1\x18\xa3\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n#w_sub_cert_sha1_expiration_too_long\x18\xa4\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12>\n e_subject_common_name_disallowed\x18\xa5\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1en_subject_common_name_included\x18\xa6\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12@\n\"e_subject_common_name_not_from_san\x18\xa7\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12G\n)e_subject_contains_noninformational_value\x18\xa8\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1e\x65_subject_contains_reserved_ip\x18\xa9\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x37\n\x19\x65_subject_country_not_iso\x18\xaa\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1b\x65_subject_empty_without_san\x18\xab\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n%e_subject_info_access_marked_critical\x18\xac\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1e\x65_subject_locality_without_org\x18\xad\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12.\n\x10\x65_subject_not_dn\x18\xae\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12;\n\x1d\x65_subject_org_without_country\x18\xaf\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12H\n*e_subject_org_without_locality_or_province\x18\xb0\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1c\x65_subject_postal_without_org\x18\xb1\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12<\n\x1e\x65_subject_province_without_org\x18\xb2\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1c\x65_subject_street_without_org\x18\xb3\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x41\n#e_utc_time_does_not_include_seconds\x18\xb4\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x34\n\x16\x65_utc_time_not_in_zulu\x18\xb5\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12:\n\x1c\x65_validity_time_not_positive\x18\xb6\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x39\n\x1b\x65_wrong_time_format_pre2050\x18\xb7\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x31\n\x13\x65_rsa_no_public_key\x18\xb8\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x45\n\'e_sub_cert_certificate_policies_missing\x18\xb9\x01 \x01(\x0b\x32\x13.zsearch.LintResult\x12\x43\n%e_sub_cert_key_usage_crl_sign_bit_set\x18\xba\x01 \x01(\x0b\x32\x13.zsearch.LintResult*\xf5\x01\n\x10LintResultStatus\x12\x18\n\x14LINT_RESULT_RESERVED\x10\x00\x12\x12\n\x0eLINT_RESULT_NA\x10\x01\x12\x12\n\x0eLINT_RESULT_NE\x10\x02\x12\x14\n\x10LINT_RESULT_PASS\x10\x03\x12\x14\n\x10LINT_RESULT_INFO\x10\x04\x12\x16\n\x12LINT_RESULT_NOTICE\x10\x05\x12\x14\n\x10LINT_RESULT_WARN\x10\x06\x12\x15\n\x11LINT_RESULT_ERROR\x10\x07\x12\x15\n\x11LINT_RESULT_FATAL\x10\x08\x12\x17\n\x13LINT_RESULT_UNKNOWN\x10\t*[\n\x0bZLintStatus\x12\x19\n\x15ZLINT_STATUS_RESERVED\x10\x00\x12\x18\n\x14ZLINT_STATUS_SUCCESS\x10\x01\x12\x17\n\x13ZLINT_STATUS_FAILED\x10\x02\x62\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_LINTRESULTSTATUS = _descriptor.EnumDescriptor(
  name='LintResultStatus',
  full_name='zsearch.LintResultStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_NA', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_NE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_PASS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_INFO', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_NOTICE', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_WARN', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_ERROR', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_FATAL', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINT_RESULT_UNKNOWN', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12017,
  serialized_end=12262,
)
_sym_db.RegisterEnumDescriptor(_LINTRESULTSTATUS)

LintResultStatus = enum_type_wrapper.EnumTypeWrapper(_LINTRESULTSTATUS)
_ZLINTSTATUS = _descriptor.EnumDescriptor(
  name='ZLintStatus',
  full_name='zsearch.ZLintStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZLINT_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZLINT_STATUS_SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZLINT_STATUS_FAILED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12264,
  serialized_end=12355,
)
_sym_db.RegisterEnumDescriptor(_ZLINTSTATUS)

ZLintStatus = enum_type_wrapper.EnumTypeWrapper(_ZLINTSTATUS)
LINT_RESULT_RESERVED = 0
LINT_RESULT_NA = 1
LINT_RESULT_NE = 2
LINT_RESULT_PASS = 3
LINT_RESULT_INFO = 4
LINT_RESULT_NOTICE = 5
LINT_RESULT_WARN = 6
LINT_RESULT_ERROR = 7
LINT_RESULT_FATAL = 8
LINT_RESULT_UNKNOWN = 9
ZLINT_STATUS_RESERVED = 0
ZLINT_STATUS_SUCCESS = 1
ZLINT_STATUS_FAILED = 2



_LINTRESULT = _descriptor.Descriptor(
  name='LintResult',
  full_name='zsearch.LintResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='zsearch.LintResult.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='zsearch.LintResult.details', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=96,
)


_ZLINT = _descriptor.Descriptor(
  name='ZLint',
  full_name='zsearch.ZLint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='zsearch.ZLint.version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='zsearch.ZLint.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.ZLint.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='infos_present', full_name='zsearch.ZLint.infos_present', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notices_present', full_name='zsearch.ZLint.notices_present', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='warnings_present', full_name='zsearch.ZLint.warnings_present', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errors_present', full_name='zsearch.ZLint.errors_present', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fatals_present', full_name='zsearch.ZLint.fatals_present', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lints', full_name='zsearch.ZLint.lints', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=333,
)


_LINTS = _descriptor.Descriptor(
  name='Lints',
  full_name='zsearch.Lints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='e_basic_constraints_not_critical', full_name='zsearch.Lints.e_basic_constraints_not_critical', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ian_bare_wildcard', full_name='zsearch.Lints.e_ian_bare_wildcard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ian_wildcard_not_first', full_name='zsearch.Lints.e_ian_wildcard_not_first', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_san_bare_wildcard', full_name='zsearch.Lints.e_san_bare_wildcard', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_san_wildcard_not_first', full_name='zsearch.Lints.e_san_wildcard_not_first', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_country_name_invalid', full_name='zsearch.Lints.e_ca_country_name_invalid', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_country_name_missing', full_name='zsearch.Lints.e_ca_country_name_missing', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_crl_sign_not_set', full_name='zsearch.Lints.e_ca_crl_sign_not_set', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n_ca_digital_signature_not_set', full_name='zsearch.Lints.n_ca_digital_signature_not_set', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_key_cert_sign_not_set', full_name='zsearch.Lints.e_ca_key_cert_sign_not_set', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_key_usage_missing', full_name='zsearch.Lints.e_ca_key_usage_missing', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_key_usage_not_critical', full_name='zsearch.Lints.e_ca_key_usage_not_critical', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_organization_name_missing', full_name='zsearch.Lints.e_ca_organization_name_missing', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ca_subject_field_empty', full_name='zsearch.Lints.e_ca_subject_field_empty', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_contains_unique_identifier', full_name='zsearch.Lints.e_cert_contains_unique_identifier', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_extensions_version_not_3', full_name='zsearch.Lints.e_cert_extensions_version_not_3', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_dv_conflicts_with_locality', full_name='zsearch.Lints.e_cab_dv_conflicts_with_locality', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_dv_conflicts_with_org', full_name='zsearch.Lints.e_cab_dv_conflicts_with_org', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_dv_conflicts_with_postal', full_name='zsearch.Lints.e_cab_dv_conflicts_with_postal', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_dv_conflicts_with_province', full_name='zsearch.Lints.e_cab_dv_conflicts_with_province', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_dv_conflicts_with_street', full_name='zsearch.Lints.e_cab_dv_conflicts_with_street', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_policy_iv_requires_country', full_name='zsearch.Lints.e_cert_policy_iv_requires_country', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_policy_iv_requires_province_or_locality', full_name='zsearch.Lints.e_cert_policy_iv_requires_province_or_locality', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_policy_ov_requires_country', full_name='zsearch.Lints.e_cert_policy_ov_requires_country', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_policy_ov_requires_province_or_locality', full_name='zsearch.Lints.e_cert_policy_ov_requires_province_or_locality', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_ov_requires_org', full_name='zsearch.Lints.e_cab_ov_requires_org', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cab_iv_requires_personal_name', full_name='zsearch.Lints.e_cab_iv_requires_personal_name', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_cert_unique_identifier_version_not_2_or_3', full_name='zsearch.Lints.e_cert_unique_identifier_version_not_2_or_3', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_dh_params_missing', full_name='zsearch.Lints.e_dh_params_missing', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_distribution_point_incomplete', full_name='zsearch.Lints.e_distribution_point_incomplete', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_distribution_point_missing_ldap_or_uri', full_name='zsearch.Lints.w_distribution_point_missing_ldap_or_uri', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_dsa_improper_modulus_or_divisor_size', full_name='zsearch.Lints.e_dsa_improper_modulus_or_divisor_size', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_dsa_shorter_than_2048_bits', full_name='zsearch.Lints.e_dsa_shorter_than_2048_bits', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ec_improper_curves', full_name='zsearch.Lints.e_ec_improper_curves', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_eku_critical_improperly', full_name='zsearch.Lints.w_eku_critical_improperly', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_business_category_missing', full_name='zsearch.Lints.e_ev_business_category_missing', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_country_name_missing', full_name='zsearch.Lints.e_ev_country_name_missing', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_locality_name_missing', full_name='zsearch.Lints.e_ev_locality_name_missing', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_organization_name_missing', full_name='zsearch.Lints.e_ev_organization_name_missing', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_serial_number_missing', full_name='zsearch.Lints.e_ev_serial_number_missing', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ev_valid_time_too_long', full_name='zsearch.Lints.e_ev_valid_time_too_long', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_aia_access_location_missing', full_name='zsearch.Lints.w_ext_aia_access_location_missing', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_aia_marked_critical', full_name='zsearch.Lints.e_ext_aia_marked_critical', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_authority_key_identifier_critical', full_name='zsearch.Lints.e_ext_authority_key_identifier_critical', index=43,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_authority_key_identifier_missing', full_name='zsearch.Lints.e_ext_authority_key_identifier_missing', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_authority_key_identifier_no_key_identifier', full_name='zsearch.Lints.e_ext_authority_key_identifier_no_key_identifier', index=45,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_cert_policy_contains_noticeref', full_name='zsearch.Lints.w_ext_cert_policy_contains_noticeref', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_cert_policy_disallowed_any_policy_qualifier', full_name='zsearch.Lints.e_ext_cert_policy_disallowed_any_policy_qualifier', index=47,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_cert_policy_duplicate', full_name='zsearch.Lints.e_ext_cert_policy_duplicate', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_cert_policy_explicit_text_ia5_string', full_name='zsearch.Lints.e_ext_cert_policy_explicit_text_ia5_string', index=49,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_cert_policy_explicit_text_includes_control', full_name='zsearch.Lints.w_ext_cert_policy_explicit_text_includes_control', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_cert_policy_explicit_text_not_nfc', full_name='zsearch.Lints.w_ext_cert_policy_explicit_text_not_nfc', index=51,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_cert_policy_explicit_text_not_utf8', full_name='zsearch.Lints.w_ext_cert_policy_explicit_text_not_utf8', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_cert_policy_explicit_text_too_long', full_name='zsearch.Lints.e_ext_cert_policy_explicit_text_too_long', index=53,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_crl_distribution_marked_critical', full_name='zsearch.Lints.w_ext_crl_distribution_marked_critical', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_duplicate_extension', full_name='zsearch.Lints.e_ext_duplicate_extension', index=55,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_freshest_crl_marked_critical', full_name='zsearch.Lints.e_ext_freshest_crl_marked_critical', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_ian_critical', full_name='zsearch.Lints.w_ext_ian_critical', index=57,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_dns_not_ia5_string', full_name='zsearch.Lints.e_ext_ian_dns_not_ia5_string', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_empty_name', full_name='zsearch.Lints.e_ext_ian_empty_name', index=59,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_no_entries', full_name='zsearch.Lints.e_ext_ian_no_entries', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_rfc822_format_invalid', full_name='zsearch.Lints.e_ext_ian_rfc822_format_invalid', index=61,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_space_dns_name', full_name='zsearch.Lints.e_ext_ian_space_dns_name', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_uri_format_invalid', full_name='zsearch.Lints.e_ext_ian_uri_format_invalid', index=63,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_uri_host_not_fqdn_or_ip', full_name='zsearch.Lints.e_ext_ian_uri_host_not_fqdn_or_ip', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_uri_not_ia5', full_name='zsearch.Lints.e_ext_ian_uri_not_ia5', index=65,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_ian_uri_relative', full_name='zsearch.Lints.e_ext_ian_uri_relative', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_key_usage_cert_sign_without_ca', full_name='zsearch.Lints.e_ext_key_usage_cert_sign_without_ca', index=67,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_key_usage_not_critical', full_name='zsearch.Lints.w_ext_key_usage_not_critical', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_key_usage_without_bits', full_name='zsearch.Lints.e_ext_key_usage_without_bits', index=69,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_name_constraints_not_critical', full_name='zsearch.Lints.e_ext_name_constraints_not_critical', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_name_constraints_not_in_ca', full_name='zsearch.Lints.e_ext_name_constraints_not_in_ca', index=71,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_policy_constraints_empty', full_name='zsearch.Lints.e_ext_policy_constraints_empty', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_policy_constraints_not_critical', full_name='zsearch.Lints.e_ext_policy_constraints_not_critical', index=73,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_policy_map_any_policy', full_name='zsearch.Lints.e_ext_policy_map_any_policy', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_policy_map_not_critical', full_name='zsearch.Lints.w_ext_policy_map_not_critical', index=75,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_policy_map_not_in_cert_policy', full_name='zsearch.Lints.w_ext_policy_map_not_in_cert_policy', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_contains_reserved_ip', full_name='zsearch.Lints.e_ext_san_contains_reserved_ip', index=77,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_san_critical_with_subject_dn', full_name='zsearch.Lints.w_ext_san_critical_with_subject_dn', index=78,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_directory_name_present', full_name='zsearch.Lints.e_ext_san_directory_name_present', index=79,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_dns_not_ia5_string', full_name='zsearch.Lints.e_ext_san_dns_not_ia5_string', index=80,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_dnsname_not_fqdn', full_name='zsearch.Lints.e_ext_san_dnsname_not_fqdn', index=81,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_edi_party_name_present', full_name='zsearch.Lints.e_ext_san_edi_party_name_present', index=82,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_empty_name', full_name='zsearch.Lints.e_ext_san_empty_name', index=83,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_missing', full_name='zsearch.Lints.e_ext_san_missing', index=84,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_no_entries', full_name='zsearch.Lints.e_ext_san_no_entries', index=85,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_not_critical_without_subject', full_name='zsearch.Lints.e_ext_san_not_critical_without_subject', index=86,
      number=88, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_other_name_present', full_name='zsearch.Lints.e_ext_san_other_name_present', index=87,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_registered_id_present', full_name='zsearch.Lints.e_ext_san_registered_id_present', index=88,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_rfc822_format_invalid', full_name='zsearch.Lints.e_ext_san_rfc822_format_invalid', index=89,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_rfc822_name_present', full_name='zsearch.Lints.e_ext_san_rfc822_name_present', index=90,
      number=92, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_space_dns_name', full_name='zsearch.Lints.e_ext_san_space_dns_name', index=91,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_uniform_resource_identifier_present', full_name='zsearch.Lints.e_ext_san_uniform_resource_identifier_present', index=92,
      number=94, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_uri_format_invalid', full_name='zsearch.Lints.e_ext_san_uri_format_invalid', index=93,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_uri_host_not_fqdn_or_ip', full_name='zsearch.Lints.e_ext_san_uri_host_not_fqdn_or_ip', index=94,
      number=96, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_uri_not_ia5', full_name='zsearch.Lints.e_ext_san_uri_not_ia5', index=95,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_san_uri_relative', full_name='zsearch.Lints.e_ext_san_uri_relative', index=96,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_subject_directory_attr_critical', full_name='zsearch.Lints.e_ext_subject_directory_attr_critical', index=97,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_subject_key_identifier_critical', full_name='zsearch.Lints.e_ext_subject_key_identifier_critical', index=98,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ext_subject_key_identifier_missing_ca', full_name='zsearch.Lints.e_ext_subject_key_identifier_missing_ca', index=99,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ext_subject_key_identifier_missing_sub_cert', full_name='zsearch.Lints.w_ext_subject_key_identifier_missing_sub_cert', index=100,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_generalized_time_does_not_include_seconds', full_name='zsearch.Lints.e_generalized_time_does_not_include_seconds', index=101,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_generalized_time_includes_fraction_seconds', full_name='zsearch.Lints.e_generalized_time_includes_fraction_seconds', index=102,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_generalized_time_not_in_zulu', full_name='zsearch.Lints.e_generalized_time_not_in_zulu', index=103,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_gtld_under_consideration', full_name='zsearch.Lints.w_gtld_under_consideration', index=104,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ian_dns_name_includes_null_char', full_name='zsearch.Lints.e_ian_dns_name_includes_null_char', index=105,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_ian_dns_name_starts_with_period', full_name='zsearch.Lints.e_ian_dns_name_starts_with_period', index=106,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_ian_iana_pub_suffix_empty', full_name='zsearch.Lints.w_ian_iana_pub_suffix_empty', index=107,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_inhibit_any_policy_not_critical', full_name='zsearch.Lints.e_inhibit_any_policy_not_critical', index=108,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_invalid_certificate_version', full_name='zsearch.Lints.e_invalid_certificate_version', index=109,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_issuer_field_empty', full_name='zsearch.Lints.e_issuer_field_empty', index=110,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_name_constraint_empty', full_name='zsearch.Lints.e_name_constraint_empty', index=111,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_name_constraint_maximum_not_absent', full_name='zsearch.Lints.e_name_constraint_maximum_not_absent', index=112,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_name_constraint_minimum_non_zero', full_name='zsearch.Lints.e_name_constraint_minimum_non_zero', index=113,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_name_constraint_on_edi_party_name', full_name='zsearch.Lints.w_name_constraint_on_edi_party_name', index=114,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_name_constraint_on_registered_id', full_name='zsearch.Lints.w_name_constraint_on_registered_id', index=115,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_name_constraint_on_x400', full_name='zsearch.Lints.w_name_constraint_on_x400', index=116,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_old_root_ca_rsa_mod_less_than_2048_bits', full_name='zsearch.Lints.e_old_root_ca_rsa_mod_less_than_2048_bits', index=117,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_old_sub_ca_rsa_mod_less_than_1024_bits', full_name='zsearch.Lints.e_old_sub_ca_rsa_mod_less_than_1024_bits', index=118,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_old_sub_cert_rsa_mod_less_than_1024_bits', full_name='zsearch.Lints.e_old_sub_cert_rsa_mod_less_than_1024_bits', index=119,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_path_len_constraint_improperly_included', full_name='zsearch.Lints.e_path_len_constraint_improperly_included', index=120,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_path_len_constraint_zero_or_less', full_name='zsearch.Lints.e_path_len_constraint_zero_or_less', index=121,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_public_key_type_not_allowed', full_name='zsearch.Lints.e_public_key_type_not_allowed', index=122,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_root_ca_basic_constraints_path_len_constraint_field_present', full_name='zsearch.Lints.w_root_ca_basic_constraints_path_len_constraint_field_present', index=123,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_root_ca_contains_cert_policy', full_name='zsearch.Lints.w_root_ca_contains_cert_policy', index=124,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_root_ca_extended_key_usage_present', full_name='zsearch.Lints.e_root_ca_extended_key_usage_present', index=125,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_rsa_exp_negative', full_name='zsearch.Lints.e_rsa_exp_negative', index=126,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_rsa_mod_factors_smaller_than_752', full_name='zsearch.Lints.w_rsa_mod_factors_smaller_than_752', index=127,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_rsa_mod_less_than_2048_bits', full_name='zsearch.Lints.e_rsa_mod_less_than_2048_bits', index=128,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_rsa_mod_not_odd', full_name='zsearch.Lints.w_rsa_mod_not_odd', index=129,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_rsa_public_exponent_not_in_range', full_name='zsearch.Lints.w_rsa_public_exponent_not_in_range', index=130,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_rsa_public_exponent_not_odd', full_name='zsearch.Lints.e_rsa_public_exponent_not_odd', index=131,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_rsa_public_exponent_too_small', full_name='zsearch.Lints.e_rsa_public_exponent_too_small', index=132,
      number=134, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_san_dns_name_includes_null_char', full_name='zsearch.Lints.e_san_dns_name_includes_null_char', index=133,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_san_dns_name_starts_with_period', full_name='zsearch.Lints.e_san_dns_name_starts_with_period', index=134,
      number=136, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_san_iana_pub_suffix_empty', full_name='zsearch.Lints.w_san_iana_pub_suffix_empty', index=135,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_serial_number_longer_than_20_octets', full_name='zsearch.Lints.e_serial_number_longer_than_20_octets', index=136,
      number=138, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_serial_number_not_positive', full_name='zsearch.Lints.e_serial_number_not_positive', index=137,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_ca_aia_does_not_contain_issuing_ca_url', full_name='zsearch.Lints.w_sub_ca_aia_does_not_contain_issuing_ca_url', index=138,
      number=140, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_aia_does_not_contain_ocsp_url', full_name='zsearch.Lints.e_sub_ca_aia_does_not_contain_ocsp_url', index=139,
      number=141, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_aia_missing', full_name='zsearch.Lints.e_sub_ca_aia_missing', index=140,
      number=142, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_ca_certificate_policies_marked_critical', full_name='zsearch.Lints.w_sub_ca_certificate_policies_marked_critical', index=141,
      number=143, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_certificate_policies_missing', full_name='zsearch.Lints.e_sub_ca_certificate_policies_missing', index=142,
      number=144, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_crl_distribution_points_does_not_contain_url', full_name='zsearch.Lints.e_sub_ca_crl_distribution_points_does_not_contain_url', index=143,
      number=145, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_crl_distribution_points_marked_critical', full_name='zsearch.Lints.e_sub_ca_crl_distribution_points_marked_critical', index=144,
      number=146, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_crl_distribution_points_missing', full_name='zsearch.Lints.e_sub_ca_crl_distribution_points_missing', index=145,
      number=147, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_ca_eku_critical', full_name='zsearch.Lints.w_sub_ca_eku_critical', index=146,
      number=148, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_ca_name_constraints_not_critical', full_name='zsearch.Lints.w_sub_ca_name_constraints_not_critical', index=147,
      number=149, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_no_dns_name_constraints', full_name='zsearch.Lints.e_sub_ca_no_dns_name_constraints', index=148,
      number=150, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_ca_no_ip_name_constraints', full_name='zsearch.Lints.e_sub_ca_no_ip_name_constraints', index=149,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_aia_does_not_contain_issuing_ca_url', full_name='zsearch.Lints.e_sub_cert_aia_does_not_contain_issuing_ca_url', index=150,
      number=152, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_aia_does_not_contain_ocsp_url', full_name='zsearch.Lints.e_sub_cert_aia_does_not_contain_ocsp_url', index=151,
      number=153, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_aia_missing', full_name='zsearch.Lints.e_sub_cert_aia_missing', index=152,
      number=154, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_cert_policy_empty', full_name='zsearch.Lints.e_sub_cert_cert_policy_empty', index=153,
      number=155, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_cert_certificate_policies_marked_critical', full_name='zsearch.Lints.w_sub_cert_certificate_policies_marked_critical', index=154,
      number=156, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_crl_distribution_points_does_not_contain_url', full_name='zsearch.Lints.e_sub_cert_crl_distribution_points_does_not_contain_url', index=155,
      number=157, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_crl_distribution_points_marked_critical', full_name='zsearch.Lints.e_sub_cert_crl_distribution_points_marked_critical', index=156,
      number=158, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_cert_eku_extra_values', full_name='zsearch.Lints.w_sub_cert_eku_extra_values', index=157,
      number=159, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_eku_missing', full_name='zsearch.Lints.e_sub_cert_eku_missing', index=158,
      number=160, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_eku_server_auth_client_auth_missing', full_name='zsearch.Lints.e_sub_cert_eku_server_auth_client_auth_missing', index=159,
      number=161, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_key_usage_cert_sign_bit_set', full_name='zsearch.Lints.e_sub_cert_key_usage_cert_sign_bit_set', index=160,
      number=162, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_or_sub_ca_using_sha1', full_name='zsearch.Lints.e_sub_cert_or_sub_ca_using_sha1', index=161,
      number=163, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w_sub_cert_sha1_expiration_too_long', full_name='zsearch.Lints.w_sub_cert_sha1_expiration_too_long', index=162,
      number=164, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_common_name_disallowed', full_name='zsearch.Lints.e_subject_common_name_disallowed', index=163,
      number=165, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n_subject_common_name_included', full_name='zsearch.Lints.n_subject_common_name_included', index=164,
      number=166, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_common_name_not_from_san', full_name='zsearch.Lints.e_subject_common_name_not_from_san', index=165,
      number=167, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_contains_noninformational_value', full_name='zsearch.Lints.e_subject_contains_noninformational_value', index=166,
      number=168, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_contains_reserved_ip', full_name='zsearch.Lints.e_subject_contains_reserved_ip', index=167,
      number=169, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_country_not_iso', full_name='zsearch.Lints.e_subject_country_not_iso', index=168,
      number=170, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_empty_without_san', full_name='zsearch.Lints.e_subject_empty_without_san', index=169,
      number=171, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_info_access_marked_critical', full_name='zsearch.Lints.e_subject_info_access_marked_critical', index=170,
      number=172, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_locality_without_org', full_name='zsearch.Lints.e_subject_locality_without_org', index=171,
      number=173, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_not_dn', full_name='zsearch.Lints.e_subject_not_dn', index=172,
      number=174, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_org_without_country', full_name='zsearch.Lints.e_subject_org_without_country', index=173,
      number=175, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_org_without_locality_or_province', full_name='zsearch.Lints.e_subject_org_without_locality_or_province', index=174,
      number=176, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_postal_without_org', full_name='zsearch.Lints.e_subject_postal_without_org', index=175,
      number=177, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_province_without_org', full_name='zsearch.Lints.e_subject_province_without_org', index=176,
      number=178, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_subject_street_without_org', full_name='zsearch.Lints.e_subject_street_without_org', index=177,
      number=179, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_utc_time_does_not_include_seconds', full_name='zsearch.Lints.e_utc_time_does_not_include_seconds', index=178,
      number=180, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_utc_time_not_in_zulu', full_name='zsearch.Lints.e_utc_time_not_in_zulu', index=179,
      number=181, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_validity_time_not_positive', full_name='zsearch.Lints.e_validity_time_not_positive', index=180,
      number=182, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_wrong_time_format_pre2050', full_name='zsearch.Lints.e_wrong_time_format_pre2050', index=181,
      number=183, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_rsa_no_public_key', full_name='zsearch.Lints.e_rsa_no_public_key', index=182,
      number=184, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_certificate_policies_missing', full_name='zsearch.Lints.e_sub_cert_certificate_policies_missing', index=183,
      number=185, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='e_sub_cert_key_usage_crl_sign_bit_set', full_name='zsearch.Lints.e_sub_cert_key_usage_crl_sign_bit_set', index=184,
      number=186, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=12014,
)

_LINTRESULT.fields_by_name['result'].enum_type = _LINTRESULTSTATUS
_ZLINT.fields_by_name['status'].enum_type = _ZLINTSTATUS
_ZLINT.fields_by_name['lints'].message_type = _LINTS
_LINTS.fields_by_name['e_basic_constraints_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ian_bare_wildcard'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ian_wildcard_not_first'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_san_bare_wildcard'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_san_wildcard_not_first'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_country_name_invalid'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_country_name_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_crl_sign_not_set'].message_type = _LINTRESULT
_LINTS.fields_by_name['n_ca_digital_signature_not_set'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_key_cert_sign_not_set'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_key_usage_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_key_usage_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_organization_name_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ca_subject_field_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_contains_unique_identifier'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_extensions_version_not_3'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_dv_conflicts_with_locality'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_dv_conflicts_with_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_dv_conflicts_with_postal'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_dv_conflicts_with_province'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_dv_conflicts_with_street'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_policy_iv_requires_country'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_policy_iv_requires_province_or_locality'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_policy_ov_requires_country'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_policy_ov_requires_province_or_locality'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_ov_requires_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cab_iv_requires_personal_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_cert_unique_identifier_version_not_2_or_3'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_dh_params_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_distribution_point_incomplete'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_distribution_point_missing_ldap_or_uri'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_dsa_improper_modulus_or_divisor_size'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_dsa_shorter_than_2048_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ec_improper_curves'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_eku_critical_improperly'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_business_category_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_country_name_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_locality_name_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_organization_name_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_serial_number_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ev_valid_time_too_long'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_aia_access_location_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_aia_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_authority_key_identifier_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_authority_key_identifier_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_authority_key_identifier_no_key_identifier'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_cert_policy_contains_noticeref'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_cert_policy_disallowed_any_policy_qualifier'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_cert_policy_duplicate'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_cert_policy_explicit_text_ia5_string'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_cert_policy_explicit_text_includes_control'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_cert_policy_explicit_text_not_nfc'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_cert_policy_explicit_text_not_utf8'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_cert_policy_explicit_text_too_long'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_crl_distribution_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_duplicate_extension'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_freshest_crl_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_ian_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_dns_not_ia5_string'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_empty_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_no_entries'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_rfc822_format_invalid'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_space_dns_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_uri_format_invalid'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_uri_host_not_fqdn_or_ip'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_uri_not_ia5'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_ian_uri_relative'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_key_usage_cert_sign_without_ca'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_key_usage_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_key_usage_without_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_name_constraints_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_name_constraints_not_in_ca'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_policy_constraints_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_policy_constraints_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_policy_map_any_policy'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_policy_map_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_policy_map_not_in_cert_policy'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_contains_reserved_ip'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_san_critical_with_subject_dn'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_directory_name_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_dns_not_ia5_string'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_dnsname_not_fqdn'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_edi_party_name_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_empty_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_no_entries'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_not_critical_without_subject'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_other_name_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_registered_id_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_rfc822_format_invalid'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_rfc822_name_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_space_dns_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_uniform_resource_identifier_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_uri_format_invalid'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_uri_host_not_fqdn_or_ip'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_uri_not_ia5'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_san_uri_relative'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_subject_directory_attr_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_subject_key_identifier_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ext_subject_key_identifier_missing_ca'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ext_subject_key_identifier_missing_sub_cert'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_generalized_time_does_not_include_seconds'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_generalized_time_includes_fraction_seconds'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_generalized_time_not_in_zulu'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_gtld_under_consideration'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ian_dns_name_includes_null_char'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_ian_dns_name_starts_with_period'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_ian_iana_pub_suffix_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_inhibit_any_policy_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_invalid_certificate_version'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_issuer_field_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_name_constraint_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_name_constraint_maximum_not_absent'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_name_constraint_minimum_non_zero'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_name_constraint_on_edi_party_name'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_name_constraint_on_registered_id'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_name_constraint_on_x400'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_old_root_ca_rsa_mod_less_than_2048_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_old_sub_ca_rsa_mod_less_than_1024_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_old_sub_cert_rsa_mod_less_than_1024_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_path_len_constraint_improperly_included'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_path_len_constraint_zero_or_less'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_public_key_type_not_allowed'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_root_ca_basic_constraints_path_len_constraint_field_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_root_ca_contains_cert_policy'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_root_ca_extended_key_usage_present'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_rsa_exp_negative'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_rsa_mod_factors_smaller_than_752'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_rsa_mod_less_than_2048_bits'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_rsa_mod_not_odd'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_rsa_public_exponent_not_in_range'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_rsa_public_exponent_not_odd'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_rsa_public_exponent_too_small'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_san_dns_name_includes_null_char'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_san_dns_name_starts_with_period'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_san_iana_pub_suffix_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_serial_number_longer_than_20_octets'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_serial_number_not_positive'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_ca_aia_does_not_contain_issuing_ca_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_aia_does_not_contain_ocsp_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_aia_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_ca_certificate_policies_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_certificate_policies_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_crl_distribution_points_does_not_contain_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_crl_distribution_points_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_crl_distribution_points_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_ca_eku_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_ca_name_constraints_not_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_no_dns_name_constraints'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_ca_no_ip_name_constraints'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_aia_does_not_contain_issuing_ca_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_aia_does_not_contain_ocsp_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_aia_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_cert_policy_empty'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_cert_certificate_policies_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_crl_distribution_points_does_not_contain_url'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_crl_distribution_points_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_cert_eku_extra_values'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_eku_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_eku_server_auth_client_auth_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_key_usage_cert_sign_bit_set'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_or_sub_ca_using_sha1'].message_type = _LINTRESULT
_LINTS.fields_by_name['w_sub_cert_sha1_expiration_too_long'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_common_name_disallowed'].message_type = _LINTRESULT
_LINTS.fields_by_name['n_subject_common_name_included'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_common_name_not_from_san'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_contains_noninformational_value'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_contains_reserved_ip'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_country_not_iso'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_empty_without_san'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_info_access_marked_critical'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_locality_without_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_not_dn'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_org_without_country'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_org_without_locality_or_province'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_postal_without_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_province_without_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_subject_street_without_org'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_utc_time_does_not_include_seconds'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_utc_time_not_in_zulu'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_validity_time_not_positive'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_wrong_time_format_pre2050'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_rsa_no_public_key'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_certificate_policies_missing'].message_type = _LINTRESULT
_LINTS.fields_by_name['e_sub_cert_key_usage_crl_sign_bit_set'].message_type = _LINTRESULT
DESCRIPTOR.message_types_by_name['LintResult'] = _LINTRESULT
DESCRIPTOR.message_types_by_name['ZLint'] = _ZLINT
DESCRIPTOR.message_types_by_name['Lints'] = _LINTS
DESCRIPTOR.enum_types_by_name['LintResultStatus'] = _LINTRESULTSTATUS
DESCRIPTOR.enum_types_by_name['ZLintStatus'] = _ZLINTSTATUS

LintResult = _reflection.GeneratedProtocolMessageType('LintResult', (_message.Message,), dict(
  DESCRIPTOR = _LINTRESULT,
  __module__ = 'zlint_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.LintResult)
  ))
_sym_db.RegisterMessage(LintResult)

ZLint = _reflection.GeneratedProtocolMessageType('ZLint', (_message.Message,), dict(
  DESCRIPTOR = _ZLINT,
  __module__ = 'zlint_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ZLint)
  ))
_sym_db.RegisterMessage(ZLint)

Lints = _reflection.GeneratedProtocolMessageType('Lints', (_message.Message,), dict(
  DESCRIPTOR = _LINTS,
  __module__ = 'zlint_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Lints)
  ))
_sym_db.RegisterMessage(Lints)


# @@protoc_insertion_point(module_scope)
